@@ -1,7 +1,7 @@
 
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.9/apps/fbsddeps/fbsddeps.cc 9473 $
-// @(#) $Id: fbsddeps.cc 9473 2017-06-07 05:12:09Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.10/apps/fbsddeps/fbsddeps.cc 9650 $
+// @(#) $Id: fbsddeps.cc 9650 2017-06-27 10:14:52Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2016
 //  All rights reserved.
@@ -61,7 +61,7 @@ extern "C" {
 
 using namespace std;
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.9/apps/fbsddeps/fbsddeps.cc 9473 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.10/apps/fbsddeps/fbsddeps.cc 9650 $");
 
 static Dwm::OptArgs  g_optargs;
 
@@ -76,19 +76,17 @@ static void GetSharedLibs(const string & filename, set<string> & libs,
   if (lddpipe) {
     regex   rgx("[ \\t]+([^ \\t]+)[ \\t]+[=][>][ \\t]+(\\/[^ \\t]+|not found)[ \\t]*",
                 regex::ECMAScript|regex::optimize);
-    regex   syslib("^[/](lib|usr[/]lib)",
-                   regex::ECMAScript|regex::optimize);
     smatch  sm;
     char    line[4096];
     while (fgets(line, 4096, lddpipe) != NULL) {
       string  s(line);
       if (regex_search(s, sm, rgx)) {
         if (sm.size() == 3) {
-          string  lib(sm[1].str());
-          if (sm[2].str() == "not found") {
-            libsNotFound.insert(lib);
+          string  lib(sm[2].str());
+          if (lib == "not found") {
+            libsNotFound.insert(sm[1].str());
           }
-          else if (! regex_search(lib, sm, syslib)) {
+          else {
             libs.insert(lib);
           }
         }
@@ -104,14 +102,11 @@ static void GetSharedLibs(const string & filename, set<string> & libs,
 //----------------------------------------------------------------------------
 void GetPackageDeps(const set<string> & libs, set<string> & packages)
 {
-  string  queryPreamble("select shlibs.name, shlibs.id," 
-                        " pkg_shlibs_provided.package_id,"
-                        " pkg_shlibs_provided.shlib_id,"
-                        " packages.name, packages.version, packages.id"
-                        " from shlibs, pkg_shlibs_provided, packages"
-                        " where shlibs.id = pkg_shlibs_provided.shlib_id"
-                        " and pkg_shlibs_provided.package_id = packages.id"
-                        " and shlibs.name = ");
+  string  queryPreamble("select packages.name, packages.version, packages.id,"
+                        " files.package_id, files.path"
+                        " from packages, files where"
+                        " packages.id = files.package_id"
+                        " and files.path = ");
   sqlite3  *ppdb;
   if (sqlite3_open_v2("/var/db/pkg/local.sqlite", &ppdb,
                       SQLITE_OPEN_READONLY, 0)
@@ -121,9 +116,9 @@ void GetPackageDeps(const set<string> & libs, set<string> & packages)
       sqlite3_stmt *ppStmt;
       if (sqlite3_prepare(ppdb, qrystr.c_str(), -1, &ppStmt, 0) == SQLITE_OK) {
         while (sqlite3_step(ppStmt) == SQLITE_ROW) {
-          string  pkgName((const char *)sqlite3_column_text(ppStmt, 4));
+          string  pkgName((const char *)sqlite3_column_text(ppStmt, 0));
           pkgName += '-';
-          pkgName += (const char *)sqlite3_column_text(ppStmt, 5);
+          pkgName += (const char *)sqlite3_column_text(ppStmt, 1);
           packages.insert(pkgName);
         }
       }
