@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.9/apps/mkfbsdmnfst/mkfbsdmnfst.cc 9009 $
-// @(#) $Id: mkfbsdmnfst.cc 9009 2017-04-11 03:07:43Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.10/apps/mkfbsdmnfst/mkfbsdmnfst.cc 9648 $
+// @(#) $Id: mkfbsdmnfst.cc 9648 2017-06-27 10:07:12Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2016
 //  All rights reserved.
@@ -65,6 +65,7 @@ extern "C" {
   #include <sys/stat.h>
   #include <sys/utsname.h>
   #include <unistd.h>
+  #include <sqlite3.h>
 }
 #include <cstdlib>
 #include <fstream>
@@ -84,7 +85,7 @@ extern "C" {
 using namespace std;
 using Dwm::FreeBSDPkg::Manifest;
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.9/apps/mkfbsdmnfst/mkfbsdmnfst.cc 9009 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.10/apps/mkfbsdmnfst/mkfbsdmnfst.cc 9648 $");
 
 static Dwm::OptArgs  g_optargs;
 
@@ -98,8 +99,6 @@ static void GetSharedLibs(const string & filename, set<string> & libs)
   if (lddpipe) {
     regex   rgx(".+[ \\t]+[=][>][ \\t]+([^ \\t]+)[ \\t]+",
                 regex::ECMAScript|regex::optimize);
-    regex   syslib("^[/](lib|usr[/]lib)",
-                   regex::ECMAScript|regex::optimize);
     smatch  sm;
     char    line[4096];
     while (fgets(line, 4096, lddpipe) != NULL) {
@@ -107,9 +106,7 @@ static void GetSharedLibs(const string & filename, set<string> & libs)
       if (regex_search(s, sm, rgx)) {
         if (sm.size() == 2) {
           string  lib(sm[1].str());
-          if (! regex_search(lib, sm, syslib)) {
-            libs.insert(lib);
-          }
+          libs.insert(lib);
         }
       }
     }
@@ -123,19 +120,29 @@ static void GetSharedLibs(const string & filename, set<string> & libs)
 //----------------------------------------------------------------------------
 static void GetPackageDeps(const set<string> & libs, set<string> & packages)
 {
-  for (auto lib : libs) {
-    string  whichcmd("pkg which -q " + lib);
-    FILE    *whichpipe = popen(whichcmd.c_str(), "r");
-    if (whichpipe) {
-      char    line[4096];
-      if (fgets(line, 4096, whichpipe) != NULL) {
-        string  s(line);
-        regex  rgx("([^\\n]+)\\n", regex::ECMAScript|regex::optimize);
-        s = regex_replace(s, rgx, "$1");
-        packages.insert(s);
+  string  queryPreamble("select packages.name, packages.version, packages.id,"
+                        " files.package_id, files.path"
+                        " from packages, files where"
+                        " packages.id = files.package_id"
+                        " and files.path = ");
+  sqlite3  *ppdb;
+  if (sqlite3_open_v2("/var/db/pkg/local.sqlite", &ppdb,
+                      SQLITE_OPEN_READONLY, 0)
+      == SQLITE_OK) {
+    for (auto lib : libs) {
+      string  qrystr(queryPreamble + '"' + lib + '"');
+      sqlite3_stmt *ppStmt;
+      if (sqlite3_prepare(ppdb, qrystr.c_str(), -1, &ppStmt, 0) == SQLITE_OK) {
+        while (sqlite3_step(ppStmt) == SQLITE_ROW) {
+          string  pkgName((const char *)sqlite3_column_text(ppStmt, 0));
+          pkgName += '-';
+          pkgName += (const char *)sqlite3_column_text(ppStmt, 1);
+          packages.insert(pkgName);
+        }
       }
-      pclose(whichpipe);
+      sqlite3_finalize(ppStmt);
     }
+    sqlite3_close_v2(ppdb);
   }
   return;
 }
@@ -334,7 +341,8 @@ static void CheckPackageDependencies(const string & dirName,
                                      Manifest & manifest)
 {
   bool    rc = true;
-  regex   rgx("/bin/|/sbin/", regex::ECMAScript|regex::optimize);
+  regex   rgx("/bin/|/sbin/|/lib/lib.+\\.so\\.",
+              regex::ECMAScript|regex::optimize);
   smatch  sm;
 
   set<string>  sharedLibs;
